@@ -4,7 +4,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 require File::Spec::Unix;
 
-$VERSION = '3.30';
+$VERSION = '3.31_03';
 $VERSION = eval $VERSION;
 
 @ISA = qw(File::Spec::Unix);
@@ -184,13 +184,13 @@ sub catdir {
             $path_unix = 1 if ($path =~ m#/#);
             $path_unix = 1 if ($path =~ /^\.\.?$/);
             my $path_vms = 0;
-            $path_vms = 1 if ($path =~ m#[\[<\]]#);
+            $path_vms = 1 if ($path =~ m#(?<!\^)[\[<\]:]#);
             $path_vms = 1 if ($path =~ /^--?$/);
             my $dir_unix = 0;
             $dir_unix = 1 if ($dir =~ m#/#);
             $dir_unix = 1 if ($dir =~ /^\.\.?$/);
             my $dir_vms = 0;
-            $dir_vms = 1 if ($dir =~ m#[\[<\]]#);
+            $dir_vms = 1 if ($dir =~ m#(?<!\^)[\[<\]:]#);
             $dir_vms = 1 if ($dir =~ /^--?$/);
 
             my $unix_mode = 0;
@@ -300,7 +300,7 @@ sub catdir {
                 $dir_unix = 1 if ($dir =~ m#/#);
                 $dir_unix = 1 if ($dir =~ /^\.\.?$/);
                 my $dir_vms = 0;
-                $dir_vms = 1 if ($dir =~ m#[\[<\]]#);
+                $dir_vms = 1 if ($dir =~ m#(?<!\^)[\[<\]:]#);
                 $dir_vms = 1 if ($dir =~ /^--?$/);
 
                 if ($dir_vms == $dir_unix) {
@@ -348,7 +348,7 @@ sub catfile {
         # of the specification in order to merge them.
         $file_unix = 1 if ($tfile =~ m#/#);
         $file_unix = 1 if ($tfile =~ /^\.\.?$/);
-        $file_vms = 1 if ($tfile =~ m#[\[<\]]#);
+        $file_vms = 1 if ($tfile =~ m#(?<!\^)[\[<\]:]#);
         $file_vms = 1 if ($tfile =~ /^--?$/);
 
         # We may know for sure what the format is.
@@ -372,7 +372,7 @@ sub catfile {
                 my $tdir = $files[$i];
                 my $tdir_vms = 0;
                 my $tdir_unix = 0;
-                $tdir_vms = 1 if ($tdir =~ m#[\[<\]]#);
+                $tdir_vms = 1 if ($tdir =~ m#(?<!\^)[\[<\]:]#);
                 $tdir_unix = 1 if ($tdir =~ m#/#);
                 $tdir_unix = 1 if ($tdir =~ /^\.\.?$/);
 
@@ -396,9 +396,7 @@ sub catfile {
 
         # if the spath ends with a directory delimiter and the file is bare,
         # then just concat them.
-        # FIX-ME: In VMS format "[]<>:" are not delimiters if preceded by '^' 
-        # Quite a bit of Perl does not know that yet.
-	if ($spath =~ /^[^\)\]\/:>]+\)\Z(?!\n)/s && basename($file) eq $file) {
+	if ($spath =~ /^(?<!\^)[^\)\]\/:>]+\)\Z(?!\n)/s && basename($file) eq $file) {
 	    $rslt = "$spath$file";
 	} else {
             if ($efs) {
@@ -409,7 +407,7 @@ sub catfile {
                 $spath_unix = 1 if ($spath =~ m#/#);
                 $spath_unix = 1 if ($spath =~ /^\.\.?$/);
                 my $spath_vms = 0;
-                $spath_vms = 1 if ($spath =~ m#[\[<\]]#);
+                $spath_vms = 1 if ($spath =~ m#(?<!\^)[\[<\]:]#);
                 $spath_vms = 1 if ($spath =~ /^--?$/);
 
                 # Assume VMS mode
@@ -530,7 +528,7 @@ sub rootdir {
 Returns a string representation of the first writable directory
 from the following list or '' if none are writable:
 
-    /tmp if C<DECC$FILENAME_REPORT_UNIX> is enabled.
+    /tmp if C<DECC$FILENAME_UNIX_REPORT> is enabled.
     sys$scratch:
     $ENV{TMPDIR}
 
@@ -620,7 +618,7 @@ sub splitpath {
     my $vmsify_path = vmsify($path);
     if ($efs) {
         my $path_vms = 0;
-        $path_vms = 1 if ($path =~ m#[\[<\]]#);
+        $path_vms = 1 if ($path =~ m#(?<!\^)[\[<\]:]#);
         $path_vms = 1 if ($path =~ /^--?$/);
         if (!$path_vms) {
             return $self->SUPER::splitpath($path, $nofile);
@@ -681,7 +679,7 @@ sub splitdir {
 						# [--.		==> [-.-.
 						# .--]		==> .-.-]
 						# [--]		==> [-.-]
-    $dirspec = "[$dirspec]" unless $dirspec =~ /[\[<]/; # make legal
+    $dirspec = "[$dirspec]" unless $dirspec =~ /(?<!\^)[\[<]/; # make legal
     $dirspec =~ s/^(\[|<)\./$1/;
     @dirs = split /(?<!\^)\./, vmspath($dirspec);
     $dirs[0] =~ s/^[\[<]//s;  $dirs[-1] =~ s/[\]>]\Z(?!\n)//s;
@@ -706,7 +704,7 @@ sub catpath {
     $dir_unix = 1 if ($dir =~ m#/#);
     $dir_unix = 1 if ($dir =~ /^\.\.?$/);
     my $dir_vms = 0;
-    $dir_vms = 1 if ($dir =~ m#[\[<\]]#);
+    $dir_vms = 1 if ($dir =~ m#(?<!\^)[\[<\]:]#);
     $dir_vms = 1 if ($dir =~ /^--?$/);
 
     if ($efs && (length($dev) == 0)) {
@@ -765,7 +763,7 @@ sub abs2rel {
     $path_unix = 1 if ($path =~ m#/#);
     $path_unix = 1 if ($path =~ /^\.\.?$/);
     my $path_vms = 0;
-    $path_vms = 1 if ($path =~ m#[\[<\]]#);
+    $path_vms = 1 if ($path =~ m#(?<!\^)[\[<\]:]#);
     $path_vms = 1 if ($path =~ /^--?$/);
 
     my $unix_mode = 0;
@@ -781,7 +779,7 @@ sub abs2rel {
     if (defined $base) {
         $base_unix = 1 if ($base =~ m#/#);
         $base_unix = 1 if ($base =~ /^\.\.?$/);
-        $base_vms = 1 if ($base =~ m#[\[<\]]#);
+        $base_vms = 1 if ($base =~ m#(?<!\^)[\[<\]:]#);
         $base_vms = 1 if ($base =~ /^--?$/);
 
         if ($path_vms == $path_unix) {
@@ -901,7 +899,7 @@ sub rel2abs {
     $path_unix = 1 if ($path =~ m#/#);
     $path_unix = 1 if ($path =~ /^\.\.?$/);
     my $path_vms = 0;
-    $path_vms = 1 if ($path =~ m#[\[<\]]#);
+    $path_vms = 1 if ($path =~ m#(?<!\^)[\[<\]:]#);
     $path_vms = 1 if ($path =~ /^--?$/);
 
     my $unix_mode = 0;
@@ -917,7 +915,7 @@ sub rel2abs {
     if (defined $base) {
         $base_unix = 1 if ($base =~ m#/#);
         $base_unix = 1 if ($base =~ /^\.\.?$/);
-        $base_vms = 1 if ($base =~ m#[\[<\]]#);
+        $base_vms = 1 if ($base =~ m#(?<!\^)[\[<\]:]#);
         $base_vms = 1 if ($base =~ /^--?$/);
 
         # If we could not determine the path mode, see if we can find out
@@ -959,7 +957,7 @@ sub rel2abs {
         if ($efs) {
             # base may have changed, so need to look up format again.
             if ($unix_mode) {
-                $base_vms = 1 if ($base =~ m#[\[<\]]#);
+                $base_vms = 1 if ($base =~ m#(?<!\^)[\[<\]:]#);
                 $base_vms = 1 if ($base =~ /^--?$/);
                 $base = unixpath($base) if $base_vms;
                 $base .= '/' unless ($base =~ m#/$#);
